@@ -36,10 +36,10 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "11.0.11";
+        "11.0.14.1";
 
     private static final String java_version_date =
-        "2021-04-20";
+        "2022-02-08";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -47,13 +47,13 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "11.0.11+9";
+        "11.0.14.1+1";
 
     private static final String VERSION_NUMBER =
-        "11.0.11";
+        "11.0.14.1";
 
     private static final String VERSION_BUILD =
-        "9";
+        "1";
 
     private static final String VERSION_PRE =
         "";
